@@ -8,15 +8,15 @@ use English qw(-no_match_vars);
 use strict;
 use warnings;
 
-my $VERSION = '2.00';
+my $VERSION = '2.10';
 my $bsversion = "BS_FirstGBrowse_$VERSION";
 
 local $OUTPUT_AUTOFLUSH = 1;
 
 my %p;
 GetOptions (
-      'chromosome=s'     => \$p{CHROMOSOME},
-			'help'           => \$p{HELP}
+  'chromosome=s' => \$p{CHROMOSOME},
+	'help'         => \$p{HELP}
 );
 pod2usage(-verbose=>99) if ($p{HELP});
 
@@ -25,7 +25,7 @@ pod2usage(-verbose=>99) if ($p{HELP});
 ################################################################################
 my $BS = Bio::BioStudio->new();
 
-$p{CHROMOSOME} = $p{CHROMOSOME} || 'Escherichia_coli_chr01_0_00';
+$p{CHROMOSOME} = $p{CHROMOSOME} || 'Escherichia_coli_MG1655_chr01_0_00';
 
 my $chr = $BS->set_chromosome(
   -chromosome => $p{CHROMOSOME},
@@ -44,7 +44,7 @@ __END__
 
 =head1 VERSION
 
-  Version 2.00
+  Version 2.10
 
 =head1 DESCRIPTION
 
@@ -57,7 +57,7 @@ Required arguments:
 Optional arguments:
 
   -c,   --chromosome : A chromosome in the repository to add to GBrowse.
-                       Defaults to Escherichia_coli_chr01_0_00
+                       Defaults to Escherichia_coli_MG1655_chr01_0_00
   -h,   --help : Display this message
 
 =cut
