@@ -8,7 +8,7 @@ Bio::BioStudio::Diff
 
 =head1 VERSION
 
-Version 2.00
+Version 2.10
 
 =head1 DESCRIPTION
 
@@ -32,9 +32,7 @@ use warnings;
 
 use base qw(Bio::Root::Root);
 
-local $| = 1;
-
-our $VERSION = 2.00;
+our $VERSION = 2.10;
 
 my %CODES = (
       1  => "deleted feature",
@@ -789,7 +787,7 @@ __END__
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2013, BioStudio developers
+Copyright (c) 2015, BioStudio developers
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -802,10 +800,10 @@ list of conditions and the following disclaimer.
 list of conditions and the following disclaimer in the documentation and/or
 other materials provided with the distribution.
 
-* The names of Johns Hopkins, the Joint Genome Institute, the Lawrence Berkeley
-National Laboratory, the Department of Energy, and the BioStudio developers may
-not be used to endorse or promote products derived from this software without
-specific prior written permission.
+* The names of Johns Hopkins, the Joint Genome Institute, the Joint BioEnergy 
+Institute, the Lawrence Berkeley National Laboratory, the Department of Energy, 
+and the BioStudio developers may not be used to endorse or promote products 
+derived from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
